@@ -3,6 +3,8 @@ from google.cloud import bigquery
 from tinybird_cdk import (connector, errors, export, formats, logger, schema,
                           utils)
 from tinybird_cdk.cloud import gcp, gcs
+from typing import Optional
+import google.api_core.exceptions
 
 
 # This connector expects the standard environment variable
@@ -193,14 +195,9 @@ class Connector(connector.SQLConnector):
 
     # https://cloud.google.com/bigquery/docs/exporting-data
     # https://cloud.google.com/bigquery/docs/reference/standard-sql/other-statements#export_data_statement
-    def _export(self, query, fmt, row_limit=None):
+    def _export(self, query, fmt, row_limit: Optional[int]):
         if fmt != formats.CSV:
             raise errors.UnsupportedFormatError(fmt)
-        if row_limit is not None:
-            rowcount_job = self.bigquery.query(f"SELECT COUNT(*) AS num_rows FROM ({query});")
-            returned_rows = next(rowcount_job.result())["num_rows"]
-            if returned_rows > row_limit:
-                raise errors.RowLimitExceeded(row_limit, returned_rows)
 
         bucket = gcp.gcs_bucket()
 
@@ -210,7 +207,22 @@ class Connector(connector.SQLConnector):
 
         uri = self.client.uri(bucket, f'{directory}/*.{fmt}')
         logger.info(f'Exporting to {uri}')
-        query_job = self.bigquery.query(f"EXPORT DATA OPTIONS (format='CSV', uri='{uri}') AS {query}")
-        query_job.result() # Wait for job to complete.
+        export_query = f"EXPORT DATA OPTIONS (format='CSV', uri='{uri}') AS {query}"
+        if row_limit is not None:
+            export_query += f" LIMIT {row_limit}"
+        self._run_query(export_query)
 
         return export.CloudDir(self.client, bucket, directory)
+    
+    def _run_query(self, query: str) -> None:
+        try:
+            query_job = self.bigquery.query(query)
+            query_job.result() # Wait for job to complete.
+        except (
+            google.api_core.exceptions.BadRequest,
+            google.api_core.exceptions.NotFound,
+            google.api_core.exceptions.Forbidden,
+        ) as err:
+            raise errors.ExternalDatasourceError(str(err)) from err
+        # Everything else bubbles up as is to be captured as an internal error
+        
\ No newline at end of file
