@@ -30,7 +30,7 @@ class Connector(connector.SQLConnector):
                 cursor.execute(sql)
                 return cursor.fetchall()
 
-    def _export(self, query, fmt, row_limit=None):
+    def _export(self, query, fmt, row_limit):
         if fmt == formats.CSV:
             dictionary = False
         elif fmt == formats.NDJSON:
