@@ -61,6 +61,52 @@ class Connector(connector.SQLConnector):
             warehouses.append(Warehouse(name=warehouse['name'], size=warehouse['size']))
         warehouses.sort(key=lambda warehouse: warehouse.name)
         return warehouses
+
+    # Create or replace Snowflake integration and stage.
+    # https://docs.snowflake.com/en/sql-reference/sql/create-storage-integration
+    # https://docs.snowflake.com/en/sql-reference/sql/create-stage
+    #
+    # The CDK needs the stage to unload data to GCS, generate signed URLs and send them to Tinybird Analytics
+    # This method is intended to be called during the Connection creation flow, to ensure these resources exist
+    #
+    # The provided Snowflake user needs 'create stage' and 'create integration' grants:
+    #     grant create stage on schema cdk.cdk_test_suite to role r_cdk_test;
+    #     grant create integration on account to role r_cdk_test;
+    #
+    # The 'allowed_location' parameter is the GCS path, including the bucket and the workspace-scoped folder.
+    # For example: gcs://tinybird-cdk-production-europe-west3/689d9d2b-633b-4900-b6cd-4a8d1d36ac3c/
+    #
+    # Returns the stage name, and the service account Snowflake generates for the integration. Tinybird Analytics
+    # has to grant this account access to the bucket.
+    def create_stage(self, allowed_location):
+        integration_name = 'tinybird_integration'
+        stage_name = 'tinybird_stage'
+
+        if not (database := config.get('SF_DATABASE')):
+            raise errors.MissingConfiguration('database')
+        if not (schema := config.get('SF_SCHEMA')):
+            raise errors.MissingConfiguration('schema')
+        
+        self._query(f'''
+            create or replace storage integration {integration_name}
+              type = external_stage
+              storage_provider = 'GCS'
+              enabled = true
+              storage_allowed_locations = ('{allowed_location}')
+        ''')
+        
+        self._query(f'''
+            create or replace stage {database}.{schema}.{stage_name}
+              url='{allowed_location}'
+              file_format = (type = csv compression = none )
+              storage_integration = {integration_name};
+        ''')
+
+        integration_properties = self._query(f'describe integration {integration_name}')
+        account = list(filter(lambda p: p['property'] == 'STORAGE_GCP_SERVICE_ACCOUNT', integration_properties))[0]['property_value']
+
+        return { "stage": f'{database}.{schema}.{stage_name}', "gcp_account": account }
+
     #
     # --- Scopes ----------------------------------------------------------------------------------
     #
