@@ -10,6 +10,11 @@ class Error(Exception):
     and wrap them as bare Error exceptions with the original one as their cause.
     '''
 
+class TinybirdClientError(Error):
+    '''
+    Superclass of all errors raised by the tb client
+    '''
+
 class UnknownConnectorError(Error):
     '''
     Raised by `connector_for()` if it gets passed an unknown connector name.
@@ -32,13 +37,13 @@ class MissingConfiguration(Error):
     def __init__(self, name):
         super().__init__(f'{name} is required')
 
-class JobError(Error):
+class JobError(TinybirdClientError):
     '''
     Raised by the Tinybird client when a job it is waiting for has `error`
     status.
     '''
 
-class RateLimitedForTooLongError(Error):
+class RateLimitedForTooLongError(TinybirdClientError):
     '''
     Raised by the Tinybird client if it accumulates one hour of consecutive
     waits for the same rate-limited request.
@@ -46,15 +51,16 @@ class RateLimitedForTooLongError(Error):
     def __init__(self, max_rate_limit_retry_s):
         super().__init__(f'Rate-limited retries exceeded {max_rate_limit_retry_s} seconds')
 
-class HTTPError(Error):
+class HTTPError(TinybirdClientError):
     '''
     Raised by the Tinybird client performs an unsuccessful request that is not
     retried.
     '''
     def __init__(self, method, response, error_message):
-        status_code = response.status_code
-        url = response.url
-        super().__init__(f'{status_code} code for {method} {url}: {error_message}')
+        self.status_code = response.status_code
+        self.url = response.url
+        self.message = error_message
+        super().__init__(f'{response.status_code} code for {method} {response.url}: {error_message}')
 
 class UnsupportedCloudServiceSchemeError(Error):
     '''
@@ -71,10 +77,11 @@ class UnsupportedCloudServiceError(Error):
     def __init__(self, service):
         super().__init__(f'The cloud service {service} is unsupported')
 
-class RowLimitExceeded(Error):
+class ExternalDatasourceError(Error):
+
+    def __init__(self, message: str):
+        self.message = message
     '''
-    Raised by `replace()` if the number of rows to be returned by the export query
-    exceeds the provided row limit (if any).
+    Raised by the external datasource
     '''
-    def __init__(self, row_limit: int, returned_rows: int):
-        super().__init__(f'The number of returned rows ({returned_rows}) exceeds the row limit of {row_limit}')
+
